@@ -4,10 +4,15 @@
 #
 # ----------------------------
 
+
+# ForceFields
+
+from global_chem_extensions.global_chem_extensions.forcefields.cgenff.cgenff_parser import CGenFFMolecule
+
 # Base Package
 
 from global_chem_extensions.global_chem_extensions import GlobalChemExtensions
 
-__all__ = ['GlobalChemExtensions']
+__all__ = ['GlobalChemExtensions', 'CGenFFMolecule']
 
 __name__ = 'GlobalChemExtensions'
\ No newline at end of file
